<?php
/*
Plugin Name: Tippy
Plugin URI: http://www.musterion.net/tippy/
Description: Simple plugin to display tooltips within your WordPress blog.
Version: 3.0.4
Author: Chris Roberts
Author URI: http://www.musterion.net/
*/

/*  Copyright 2009 Chris Roberts (email : columcille@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$Tippy_Version = "3.0.4";
$Tippy_Loaded = 0;

// Add to the Admin function list
if (! function_exists('tippy_addoptions')) {
  function tippy_addoptions() {
    if (function_exists('add_options_page')) {
      add_options_page('Tippy Plugin Options', 'Tippy', 9, basename(__FILE__), 'tippy_options_subpanel');
    }
  }
}

if (! function_exists('tippy_options_subpanel')) {
  function tippy_options_subpanel() {
    global $wpdb, $table_prefix, $Tippy_Version;

    if (isset($_POST['info_update'])) {
		update_option('tippy_tipPosition', $_POST['tippy_tipPosition']);
		update_option('tippy_openTip', $_POST['tippy_openTip']);

		echo '<div class="updated"><p><strong>Your options have been updated.</strong></p></div>';
    }
?>

<style type="text/css">
div.tippyOptionSection {
 margin-bottom: 20px;
 margin-left: 10px;
}

span.tippyOptionLabel {
 font-size: 16px;
}

div.tippyOptions {
 margin-left: 15px;
}

div.tippyOptionLeft {
 width: 125px;
 float: left;
}

div.tippyOptionRight {
 float: left;
}

div.clearOptions {
 margin-bottom: 5px;
 clear: both;
}
</style>

<div class="wrap">
	<h2>Tippy Options</h2>
	<form method="post">

	<span class="tippyOptionLabel">How to use Tippy</span><br />
	<div class="tippyOptionSection">
		Example:<br />
        [tippy title="example tooltip" reference="http://www.musterion.net/" header="on"]This is my nifty tooltip![/tippy]<br /><br />
		Be sure and include the title attribute or nothing will happen. You can include html between the tippy tags. The reference tag is optional. If set, the tooltip header will link to the reference. Header is also optional and controls whether or not the tooltip displays a header.<br /><br />
		Tooltip look can be set up via CSS. Look in your tippy plugin directory at the file dom_tooltip.css and make changes there.
	</div>

    <span class="tippyOptionLabel">Tooltip Display Options</span><br />
	<div class="tippyOptionSection">
	    Here you can set default options for the tooltip. Note that some of these options will not work right together and are auto-adjusted by the plugin.<br /><br />

		<div class="tippyOptions">
        	How should the tooltip be activated? By hovering over the link or by clicking the link?<br />
			<input id="tippy_openTip_hover" name="tippy_openTip"  type="radio" value="hover" <?php if(get_option('tippy_openTip') == "hover") echo "checked" ?> />
				<label for="tippy_openTip_hover" title="Tooltip opens when user hovers over the link">
					Tooltip opens on hover
				</label><br />

			<input id="tippy_openTip_click" name="tippy_openTip" type="radio" value="click" <?php if(get_option('tippy_openTip') == "click") echo "checked" ?> />
				<label for="tippy_openTip_click" title="Tooltip opens when user clicks the link">
					Tooltip opens on click
				</label><br /><br />
		</div>
	</div>

    <input type="submit" name="info_update" value="Update Options" /><br /><br />

	</form>
</div>

<?php
  }
}

if (! function_exists('tippy_getspot')) {
	function tippy_getspot($content) {

		preg_match_all('/\[tippy([^\]]+)?\]([^\[]+)\[\/tippy\]/', $content, $tippyMatches);
		for ($i = 0 ; $i < sizeof($tippyMatches[0]) ; $i++)
		{
			$options = $tippyMatches[1][$i];
			$tippyText = $tippyMatches[2][$i];

			$tippyTitle = "";
			$tippyHref = "";

			preg_match('/title=["\']([^"]+)["\']/', $options, $titles);
			if (is_array($titles))
			{
				$tippyTitle = $titles[1];
			}

			preg_match('/reference=["\']([^"]+)["\']/', $options, $hrefs);
			if (is_array($hrefs))
			{
				$tippyHref = $hrefs[1];
			}

			preg_match('/header=["\']((?:on|off|yes|no){1})["\']/', $options, $headers);
			if (is_array($headers))
			{
				$header = $headers[1];
			}

			$tippyTitle = str_replace("\\", "\\\\", $tippyTitle);
			$tippyNewTitle = str_replace("'", "&#8217;", $tippyTitle);

			$tippyNewText = str_replace("\n", "", $tippyText);
			$tippyNewText = str_replace("\r", "", $tippyNewText);
			$tippyNewText = str_replace("'", "&#8217;", $tippyNewText);
			$tippyNewText = str_replace("\\", "&#92;", $tippyNewText);
			$tippyNewText = str_replace("(", "&#40;", $tippyNewText);
			$tippyNewText = str_replace(")", "&#41;", $tippyNewText);

			if ($tippyHref != "")
			{
				$addHref = $tippyHref;
			} else {
				$addHref = "";
			}
			
			if (get_option('tippy_openTip') == "hover")
			{
				$activateTippy = "onMouseOver";
				
				if ($tippyHref != "")
				{
					$addHref = 'href="'. $tippyHref .'" ';
				}
			} else {
				$activateTippy = "onMouseUp";
				$addHref = "";
			}

			if ($header == "on" || $header == "yes" || $header == "")
			{
				$tippyHeader = trim($tippyNewTitle);
			} else {
				$tippyHeader = "";
			}

			$tippyString = '<a '. $addHref .'class="tippy_link" '. $activateTippy .'="domTip_toolText(\'tip'. $i .'\', \''. htmlentities($tippyNewText) .'\', \''. $tippyHeader .'\', \''. $tippyHref .'\');" onMouseOut="domTip_clearTip(\'false\')">'. $tippyTitle .'</a>';

			$content = str_replace($tippyMatches[0][$i], $tippyString, $content);
		}

		return $content;
	}
}

if (! function_exists('tippy_display')) {
	$tippy_setdisplay = 0;

	function tippy_display($content = '') {
		global $tippy_setdisplay, $wpdb;

		// The following conditional will hopefully prevent a problem
                // where the echo statement will interrupt redirects from the
                // comment page.
                if (empty($_POST['comment_post_ID']))
  		{		
			$wpurl = get_bloginfo('wpurl');

			if ($tippy_setdisplay == 0)
			{
				$tippy_setdisplay = 1;

				$content .= '<link rel="stylesheet" type="text/css" href="'. $wpurl .'/wp-content/plugins/tippy/dom_tooltip.css" media="screen" />';
				$content .= '<script type="text/javascript" src="'. $wpurl .'/wp-content/plugins/tippy/dom_tooltip.js"></script>';
			}

			echo $content;
		}
	}
}

if (! function_exists('tippy_activate'))
{
	function tippy_activate()
	{
		$Tippy_Version = "3.0.3";
		
		if (!get_option('tippy_openTip'))
		{
			update_option('tippy_openTip', 'hover');
		}

		update_option('tippy_version', $Tippy_Version);
	}
	
	register_activation_hook(__FILE__, 'tippy_activate');
}

add_filter('the_content', 'tippy_getspot', 4);
add_action('wp_head', 'tippy_display', 40);
add_action('admin_menu', 'tippy_addoptions');

add_filter('comment_text', 'tippy_getspot', 4);
add_filter('comment_text', 'tippy_display', 40);

?>